@@ -442,26 +442,16 @@ py_madfile_read(PyObject * self, PyObject * args) {
 
 	/* left channel */
 	sample = madfixed_to_short(MAD_SYNTH(self).pcm.samples[0][i]);
-#ifdef BIGENDIAN
-	*(buffy++) = sample >> 8;
-	*(buffy++) = sample & 0xFF;
-#else
 	*(buffy++) = sample & 0xFF;
 	*(buffy++) = sample >> 8;
-#endif
 
 	/* right channel. 
 	 * if the decoded stream is monophonic then the right channel
 	 * is the same as the left one */
 	if (MAD_NCHANNELS(&MAD_FRAME(self).header) == 2)
 	    sample = madfixed_to_short(MAD_SYNTH(self).pcm.samples[1][i]);
-#ifdef BIGENDIAN
-	*(buffy++) = sample >> 8;
-	*(buffy++) = sample & 0xFF;
-#else
 	*(buffy++) = sample & 0xFF;
 	*(buffy++) = sample >> 8;
-#endif
     }
   
     Py_END_ALLOW_THREADS
@@ -553,6 +543,7 @@ py_madfile_seek_time(PyObject * self, PyObject * args) {
 
     mad_timer_set(&MAD_TIMER(self), 0, pos, 1000);
 
+    Py_INCREF(Py_None);
     return Py_None;
 }
 
