@@ -3,6 +3,7 @@
 import sys, os.path
 
 sys.path.insert(0, "build/lib.linux-ppc-2.3")
+sys.path.insert(0, "build/lib.linux-i686-2.3")
 
 import socket, urlparse
 import mad, ao
@@ -24,7 +25,7 @@ def madradio(url):
     mf = mad.MadFile(file)
     print "bitrate %lu bps" % mf.bitrate()
     print "samplerate %d Hz" % mf.samplerate()
-    dev = ao.AudioDevice('oss', bits=16, rate=mf.samplerate())
+    dev = ao.AudioDevice('alsa09', bits=16, rate=mf.samplerate())
     while True:
         buffy = mf.read()
         if buffy is None:
